@@ -1,4 +1,4 @@
-__version__ = '0.2.2'
+__version__ = '0.2.5'
 import json
 import os
 import termcolor
@@ -17,8 +17,10 @@ class DB:
     """
     Initializes new instance of database. (Do not call as script).
     """
-
-    self.name = kwargs.get("name")
+    if kwargs == {} or kwargs['config'] == {}:
+      self.name = 'myDB'
+    else:
+      self.name = kwargs['config']['name']
     self.__createFile__()
   def __repr__(self):
     return "Database Object"
@@ -31,7 +33,7 @@ class DB:
 
     if not path.exists('./DB'):
       os.mkdir('DB')
-    if not path.exists(f'./DB{self.name}.json'):
+    if not os.path.isfile(f'./DB/{self.name}.json'):
       with open(f'./DB/{self.name}.json', 'w') as db:
         pass
     else: 
@@ -41,6 +43,7 @@ class DB:
     """
     Returns all the information in the database.
     """
+
     if not path.exists(f'./DB/{self.name}.json'):
       self.__createFile__()
     rDB = open(f'./DB/{self.name}.json', 'r')
@@ -69,8 +72,7 @@ class DB:
     for x in range(len(arr)):
       if arr[x]['key'] == key:
         return arr[x]['data']
-      else:
-        return print(colored(f'Error: \"{key}\" not found in database.', 'red'))
+    return print(colored(f'Error: \"{key}\" not found in database.', 'red'))
 	
   def set(self, key, data):
     """
